comment constant
IconData
const comment
Regular Comment icon
https://fontawesome.com/icons/comment?style=regular Right Speech Bubble, answer, bubble, chat, commenting, conversation, conversation, discussion, feedback, message, note, notification, sms, speech, talk, talking, texting
Implementation
static const IconData comment = IconDataRegular(0xf075);