message constant
IconData
const message
Regular Message icon
https://fontawesome.com/icons/message?style=regular answer, bubble, chat, commenting, conversation, conversation, discussion, feedback, message, note, notification, sms, speech, talk, talking, texting
Implementation
static const IconData message = IconDataRegular(0xf27a);