mobileVibrate constant

IconData const mobileVibrate

Solid Mobile Vibrate icon

https://fontawesome.com/icons/mobile-vibrate?style=solid android, call, cell, cell phone, device, haptic, mobile, mobile phone, notification, number, phone, screen, telephone, text

Implementation

static const IconData mobileVibrate = IconDataSolid(0xe816);