solidComment constant

IconData const solidComment

Solid Comment icon

https://fontawesome.com/icons/comment?style=solid Right Speech Bubble, answer, bubble, chat, commenting, conversation, conversation, discussion, feedback, message, note, notification, sms, speech, talk, talking, texting

Implementation

static const IconData solidComment = IconDataSolid(0xf075);