solidMessage constant

IconData const solidMessage

Solid Message icon

https://fontawesome.com/icons/message?style=solid answer, bubble, chat, commenting, conversation, conversation, discussion, feedback, message, note, notification, sms, speech, talk, talking, texting

Implementation

static const IconData solidMessage = IconDataSolid(0xf27a);