upRightAndDownLeftFromCenter constant
IconData
const upRightAndDownLeftFromCenter
Solid Up Right And Down Left From Center icon
https://fontawesome.com/icons/up-right-and-down-left-from-center?style=solid arrows, bigger, enlarge, expand, fullscreen, maximize, resize, resize, scale, size
Implementation
static const IconData upRightAndDownLeftFromCenter = IconDataSolid(0xf424);