solidComments constant
IconData
const solidComments
Solid Comments icon
https://fontawesome.com/icons/comments?style=solid Two Speech Bubbles, answer, bubble, chat, commenting, conversation, conversation, discussion, feedback, message, note, notification, sms, speech, talk, talking, texting
Implementation
static const IconData solidComments = IconDataSolid(0xf086);